diff --git a/webapp/web/templates/freemarker/body/partials/individual/lib-properties.ftl b/webapp/web/templates/freemarker/body/partials/individual/lib-properties.ftl
index b6cdb1112..069725d05 100644
--- a/webapp/web/templates/freemarker/body/partials/individual/lib-properties.ftl
+++ b/webapp/web/templates/freemarker/body/partials/individual/lib-properties.ftl
@@ -118,12 +118,12 @@ name will be used as the label. -->
<#-- Don't assume that if the mainImage property is populated, there is a thumbnail image (though that is the general case).
If there's a mainImage statement but no thumbnail image, treat it as if there is no image. -->
<#if (mainImage.statements)?has_content && thumbUrl?has_content>
-
+
<@p.editingLinks mainImage.statements[0] showEditLinks />
<#else>
<@p.addLinkWithLabel mainImage showEditLinks "Photo" />
<#if placeholderImage?has_content>
-
+
#if>
#if>
diff --git a/webapp/web/js/imageUpload/imageUploadUtils.js b/webapp/web/js/imageUpload/imageUploadUtils.js
index ef5d5295c..90c7029d5 100644
--- a/webapp/web/js/imageUpload/imageUploadUtils.js
+++ b/webapp/web/js/imageUpload/imageUploadUtils.js
@@ -2,12 +2,10 @@
$(document).ready(function(){
- // Confirmation alert for photo deletion
- $('a.thumbnail').click(function(){
+ // Confirmation alert for photo deletion in image upload and individual templates
+ $('#photoUploadDefaultImage a.thumbnail,#share-contact a:eq(2)').click(function(){
+ //$('#share-contact a [title="delete this relationship"]').click(function(){
var answer = confirm('Are you sure you want to delete your photo?');
return answer;
});
-
-});
-
-
+});
\ No newline at end of file